==> rebul-1.0.1.tgz: package/es/TextField/TextField.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import * as sharedPropTypes from '../_prop-types';

import Field from '../Field/Field';
import FieldBody from '../Field/FieldBody';
import FieldControl from '../Field/FieldControl';
import FieldLabel from '../Field/FieldLabel';

var TextField = function TextField(_ref) {
  var _classNames;

  var autoComplete = _ref.autoComplete,
      autoFocus = _ref.autoFocus,
      children = _ref.children,
      className = _ref.className,
      color = _ref.color,
      helpText = _ref.helpText,
      inputProps = _ref.inputProps,
      inputSize = _ref.inputSize,
      isDisabled = _ref.isDisabled,
      isExpanded = _ref.isExpanded,
      isLoading = _ref.isLoading,
      isHorizontal = _ref.isHorizontal,
      isReadOnly = _ref.isReadOnly,
      isRounded = _ref.isRounded,
      labelComponent = _ref.labelComponent,
      labelName = _ref.labelName,
      labelSize = _ref.labelSize,
      leftAddonComponent = _ref.leftAddonComponent,
      leftIconName = _ref.leftIconName,
      max = _ref.max,
      maxLength = _ref.maxLength,
      min = _ref.min,
      minLength = _ref.minLength,
      name = _ref.name,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      pattern = _ref.pattern,
      placeholder = _ref.placeholder,
      rightAddonComponent = _ref.rightAddonComponent,
      rightIconName = _ref.rightIconName,
      spellCheck = _ref.spellCheck,
      state = _ref.state,
      step = _ref.step,
      value = _ref.value,
      props = _objectWithoutProperties(_ref, ['autoComplete', 'autoFocus', 'children', 'className', 'color', 'helpText', 'inputProps', 'inputSize', 'isDisabled', 'isExpanded', 'isLoading', 'isHorizontal', 'isReadOnly', 'isRounded', 'labelComponent', 'labelName', 'labelSize', 'leftAddonComponent', 'leftIconName', 'max', 'maxLength', 'min', 'minLength', 'name', 'onBlur', 'onChange', 'onFocus', 'pattern', 'placeholder', 'rightAddonComponent', 'rightIconName', 'spellCheck', 'state', 'step', 'value']);

  return React.createElement(
    Field,
    _extends({ isHorizontal: isHorizontal }, props),
    (labelName || labelComponent) && React.createElement(
      FieldLabel,
      { isHorizontal: isHorizontal, isNormal: true, size: labelSize },
      labelName || labelComponent
    ),
    React.createElement(
      FieldBody,
      null,
      React.createElement(
        Field,
        { color: color, hasAddons: Boolean(leftAddonComponent || rightAddonComponent), helpText: helpText },
        leftAddonComponent && React.createElement(
          FieldControl,
          null,
          leftAddonComponent
        ),
        React.createElement(
          FieldControl,
          {
            color: color,
            isExpanded: isExpanded,
            isLoading: isLoading,
            leftIconName: leftIconName,
            rightIconName: rightIconName
          },
          React.createElement('input', _extends({
            'aria-label': labelName,
            autoComplete: autoComplete,
            autoFocus: autoFocus,
            className: classNames('input', (_classNames = {}, _classNames['is-' + color] = Boolean(color), _classNames['is-' + inputSize] = Boolean(inputSize), _classNames['is-' + state] = Boolean(state), _classNames['is-rounded'] = isRounded, _classNames[className] = Boolean(className), _classNames)),
            disabled: isDisabled,
            max: max,
            maxLength: maxLength,
            min: min,
            minLength: minLength,
            name: name,
            onBlur: onBlur,
            onChange: onChange,
            onFocus: onFocus,
            pattern: pattern,
            placeholder: placeholder,
            readOnly: isReadOnly,
            spellCheck: spellCheck,
            step: step,
            value: value
          }, inputProps))
        ),
        rightAddonComponent && React.createElement(
          FieldControl,
          null,
          rightAddonComponent
        )
      )
    )
  );
};

TextField.propTypes = process.env.NODE_ENV !== "production" ? {
  /** Set an autocomplete attribute on the field */
  autoComplete: PropTypes.string,
  /** Automatically set focus to the field */
  autoFocus: PropTypes.bool,
  children: PropTypes.node,
  className: PropTypes.string,
  /** Color of input field. */
  color: sharedPropTypes.color,
  /** Displays help text */
  helpText: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  inputProps: PropTypes.object,
  /** The label that appears above the input */
  labelComponent: PropTypes.element,
  /** The label that appears above the input */
  labelName: PropTypes.string,
  /** Size of the label field */
  labelSize: sharedPropTypes.size,
  /** Addon component to display on the left of the field */
  leftAddonComponent: PropTypes.element,
  /** Name of left field icon */
  leftIconName: PropTypes.string,
  /** Size of the input field */
  inputSize: sharedPropTypes.size,
  /** Disable the input field */
  isDisabled: PropTypes.bool,
  /** Is input field expanded when addon component exists */
  isExpanded: PropTypes.bool,
  /** Input field is loading */
  isLoading: PropTypes.bool,
  /** Input field is horizontal */
  isHorizontal: PropTypes.bool,
  /** Input field is read only */
  isReadOnly: PropTypes.bool,
  /** Input field is rounded */
  isRounded: PropTypes.bool,
  /** Max value for numeric field */
  max: PropTypes.number,
  /** Max length for a alphanumeric field */
  maxLength: PropTypes.number,
  /** Min value for numeric field */
  min: PropTypes.number,
  /** Min length for a alphanumeric field */
  minLength: PropTypes.number,
  /** Name of the input field */
  name: PropTypes.string,
  /** Function to invoke on blur */
  onBlur: PropTypes.func,
  /** Function to invoke on change */
  onChange: PropTypes.func,
  /** Function to invoke on focus */
  onFocus: PropTypes.func,
  /** Regex to check value against */
  pattern: PropTypes.string,
  /** Placeholder of the input */
  placeholder: PropTypes.string,
  /** Addon component to display on the right of the field */
  rightAddonComponent: PropTypes.element,
  /** Name of right field icon */
  rightIconName: PropTypes.string,
  /** Enable spell check for input field */
  spellCheck: PropTypes.bool,
  /** State of field */
  state: sharedPropTypes.state,
  /** Increment/decrement step value for numeric field */
  step: PropTypes.number,
  /** Type of input */
  type: PropTypes.string,
  /** Value of the input */
  value: PropTypes.string
} : {};

TextField.defaultProps = {
  autoComplete: null,
  autoFocus: false,
  children: null,
  className: null,
  color: null,
  helpText: null,
  labelComponent: null,
  labelName: null,
  labelSize: null,
  leftAddonComponent: null,
  leftIconName: null,
  inputProps: {},
  inputSize: null,
  isDisabled: false,
  isExpanded: false,
  isLoading: false,
  isHorizontal: false,
  isReadOnly: false,
  isRounded: false,
  max: null,
  maxLength: null,
  min: null,
  minLength: null,
  name: null,
  onBlur: null,
  onChange: null,
  onFocus: null,
  pattern: null,
  placeholder: null,
  rightAddonComponent: null,
  rightIconName: null,
  spellCheck: false,
  state: null,
  step: null,
  type: 'text',
  value: undefined
};

export default TextField;

==> rebul-1.0.2.tgz: package/es/TextField/TextField.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import * as sharedPropTypes from '../_prop-types';

import Field from '../Field/Field';
import FieldBody from '../Field/FieldBody';
import FieldControl from '../Field/FieldControl';
import FieldLabel from '../Field/FieldLabel';

var TextField = function TextField(_ref) {
  var _classNames;

  var autoComplete = _ref.autoComplete,
      autoFocus = _ref.autoFocus,
      children = _ref.children,
      className = _ref.className,
      color = _ref.color,
      helpText = _ref.helpText,
      inputProps = _ref.inputProps,
      inputSize = _ref.inputSize,
      isDisabled = _ref.isDisabled,
      isExpanded = _ref.isExpanded,
      isLoading = _ref.isLoading,
      isHorizontal = _ref.isHorizontal,
      isReadOnly = _ref.isReadOnly,
      isRounded = _ref.isRounded,
      labelComponent = _ref.labelComponent,
      labelName = _ref.labelName,
      labelSize = _ref.labelSize,
      leftAddonComponent = _ref.leftAddonComponent,
      leftIconName = _ref.leftIconName,
      max = _ref.max,
      maxLength = _ref.maxLength,
      min = _ref.min,
      minLength = _ref.minLength,
      name = _ref.name,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      pattern = _ref.pattern,
      placeholder = _ref.placeholder,
      rightAddonComponent = _ref.rightAddonComponent,
      rightIconName = _ref.rightIconName,
      spellCheck = _ref.spellCheck,
      state = _ref.state,
      step = _ref.step,
      value = _ref.value,
      props = _objectWithoutProperties(_ref, ['autoComplete', 'autoFocus', 'children', 'className', 'color', 'helpText', 'inputProps', 'inputSize', 'isDisabled', 'isExpanded', 'isLoading', 'isHorizontal', 'isReadOnly', 'isRounded', 'labelComponent', 'labelName', 'labelSize', 'leftAddonComponent', 'leftIconName', 'max', 'maxLength', 'min', 'minLength', 'name', 'onBlur', 'onChange', 'onFocus', 'pattern', 'placeholder', 'rightAddonComponent', 'rightIconName', 'spellCheck', 'state', 'step', 'value']);

  return React.createElement(
    Field,
    _extends({ isHorizontal: isHorizontal }, props),
    (labelName || labelComponent) && React.createElement(
      FieldLabel,
      { isHorizontal: isHorizontal, isNormal: true, size: labelSize },
      labelName || labelComponent
    ),
    React.createElement(
      FieldBody,
      null,
      React.createElement(
        Field,
        { color: color, helpText: helpText },
        React.createElement(
          Field,
          { hasAddons: Boolean(leftAddonComponent || rightAddonComponent) },
          leftAddonComponent && React.createElement(
            FieldControl,
            null,
            leftAddonComponent
          ),
          React.createElement(
            FieldControl,
            {
              color: color,
              isExpanded: isExpanded,
              isLoading: isLoading,
              leftIconName: leftIconName,
              rightIconName: rightIconName
            },
            React.createElement('input', _extends({
              'aria-label': labelName,
              autoComplete: autoComplete,
              autoFocus: autoFocus,
              className: classNames('input', (_classNames = {}, _classNames['is-' + color] = Boolean(color), _classNames['is-' + inputSize] = Boolean(inputSize), _classNames['is-' + state] = Boolean(state), _classNames['is-rounded'] = isRounded, _classNames[className] = Boolean(className), _classNames)),
              disabled: isDisabled,
              max: max,
              maxLength: maxLength,
              min: min,
              minLength: minLength,
              name: name,
              onBlur: onBlur,
              onChange: onChange,
              onFocus: onFocus,
              pattern: pattern,
              placeholder: placeholder,
              readOnly: isReadOnly,
              spellCheck: spellCheck,
              step: step,
              value: value
            }, inputProps))
          ),
          rightAddonComponent && React.createElement(
            FieldControl,
            null,
            rightAddonComponent
          )
        )
      )
    )
  );
};

TextField.propTypes = process.env.NODE_ENV !== "production" ? {
  /** Set an autocomplete attribute on the field */
  autoComplete: PropTypes.string,
  /** Automatically set focus to the field */
  autoFocus: PropTypes.bool,
  children: PropTypes.node,
  className: PropTypes.string,
  /** Color of input field. */
  color: sharedPropTypes.color,
  /** Displays help text */
  helpText: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  inputProps: PropTypes.object,
  /** The label that appears above the input */
  labelComponent: PropTypes.element,
  /** The label that appears above the input */
  labelName: PropTypes.string,
  /** Size of the label field */
  labelSize: sharedPropTypes.size,
  /** Addon component to display on the left of the field */
  leftAddonComponent: PropTypes.element,
  /** Name of left field icon */
  leftIconName: PropTypes.string,
  /** Size of the input field */
  inputSize: sharedPropTypes.size,
  /** Disable the input field */
  isDisabled: PropTypes.bool,
  /** Is input field expanded when addon component exists */
  isExpanded: PropTypes.bool,
  /** Input field is loading */
  isLoading: PropTypes.bool,
  /** Input field is horizontal */
  isHorizontal: PropTypes.bool,
  /** Input field is read only */
  isReadOnly: PropTypes.bool,
  /** Input field is rounded */
  isRounded: PropTypes.bool,
  /** Max value for numeric field */
  max: PropTypes.number,
  /** Max length for a alphanumeric field */
  maxLength: PropTypes.number,
  /** Min value for numeric field */
  min: PropTypes.number,
  /** Min length for a alphanumeric field */
  minLength: PropTypes.number,
  /** Name of the input field */
  name: PropTypes.string,
  /** Function to invoke on blur */
  onBlur: PropTypes.func,
  /** Function to invoke on change */
  onChange: PropTypes.func,
  /** Function to invoke on focus */
  onFocus: PropTypes.func,
  /** Regex to check value against */
  pattern: PropTypes.string,
  /** Placeholder of the input */
  placeholder: PropTypes.string,
  /** Addon component to display on the right of the field */
  rightAddonComponent: PropTypes.element,
  /** Name of right field icon */
  rightIconName: PropTypes.string,
  /** Enable spell check for input field */
  spellCheck: PropTypes.bool,
  /** State of field */
  state: sharedPropTypes.state,
  /** Increment/decrement step value for numeric field */
  step: PropTypes.number,
  /** Type of input */
  type: PropTypes.string,
  /** Value of the input */
  value: PropTypes.string
} : {};

TextField.defaultProps = {
  autoComplete: null,
  autoFocus: false,
  children: null,
  className: null,
  color: null,
  helpText: null,
  labelComponent: null,
  labelName: null,
  labelSize: null,
  leftAddonComponent: null,
  leftIconName: null,
  inputProps: {},
  inputSize: null,
  isDisabled: false,
  isExpanded: false,
  isLoading: false,
  isHorizontal: false,
  isReadOnly: false,
  isRounded: false,
  max: null,
  maxLength: null,
  min: null,
  minLength: null,
  name: null,
  onBlur: null,
  onChange: null,
  onFocus: null,
  pattern: null,
  placeholder: null,
  rightAddonComponent: null,
  rightIconName: null,
  spellCheck: false,
  state: null,
  step: null,
  type: 'text',
  value: undefined
};

export default TextField;
